==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-networkmonitor/translations/networkmonitor_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Ağ arayüzü &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Gönderilen %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Alınan %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Ağ İzleme Ayarları</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Arayüz</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modem</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Kablosuz</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Simge</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-networkmonitor/translations/networkmonitor_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Ağ arayüzü &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Gönderilen %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Alınan %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>PB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Ağ İzleme ayarları</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Arayüz</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modem</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Kablosuz</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Simge</translation>
    </message>
</context>
</TS>
